utils

package
v0.1.24 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 26, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CutHostedZonePrefix added in v0.1.19

func CutHostedZonePrefix(s string) string

CutHostedZonePrefix removes the 'hosted-zone' prefix from AWS hosted zone IDs

func FetchTag

func FetchTag(tags []types.Tag, key string) string

FetchTag returns the value of the AWS tag with the key s or an empty string if the tag is not found.

func GetRegionsFromDB

func GetRegionsFromDB(ctx context.Context) ([]models.Region, error)

GetRegionsFromDB gets the AWS Regions from the database.

func MaybeSkipRetry added in v0.1.22

func MaybeSkipRetry(err error) error

MaybeSkipRetry wraps known AWS errors with asynq.SkipRetry, so that the tasks from which these errors originate from won't be retried.

func RestoreAsteriskPrefix added in v0.1.19

func RestoreAsteriskPrefix(route string) string

RestoreAsteriskPrefix checks whether the string starts with a \052 prefix and swaps it with an asterisk for internal storage. ex: \052.inventory.gardener.com becomes *.inventory.gardener.com

Types

This section is empty.

Jump to